==> qtsmbstatus_2.1.3.orig.tar.gz: qtsmbstatus-2.1.3/client/tr/qtsmbstatus_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>LogForm</name>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Machine</source>
        <translation>Macchina</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Utente</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Servizio</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Apri il file</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindows</name>
    <message>
        <source>Show CIFS/SMB activities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>Configura</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>Minimizza</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Ripristina</translation>
    </message>
    <message>
        <source>Thanks to:</source>
        <translation>Ringraziamenti a:</translation>
    </message>
    <message>
        <source>This program is licensed to you under the terms of the GNU General Public License version 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find text</source>
        <translation>Trova testo</translation>
    </message>
    <message>
        <source>Text not found.</source>
        <translation>Testo non trovato.</translation>
    </message>
    <message>
        <source>User %1 has opened share %2 (%3)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User %1 has opened file %2 (%3)</source>
        <translation>L&apos;utente %1 ha aperto il file %2 (%3)</translation>
    </message>
    <message>
        <source>CIFS/SMB activities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Message to send</source>
        <translation>Messaggio da inviare</translation>
    </message>
    <message>
        <source>Message to send to %1:</source>
        <translation>Messaggio da inviare a %1:</translation>
    </message>
    <message>
        <source>Do you really want to disconnect user %1 ?</source>
        <translation>Si vuole davvero disconnettere l&apos;utente %1 ?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Si</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;No</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Proprieta&apos;</translation>
    </message>
    <message>
        <source>Send out message to all users</source>
        <translation>Spedire il messaggio a tutti gli utenti</translation>
    </message>
    <message>
        <source>Send out message to</source>
        <translation>Spedire il messaggio a</translation>
    </message>
    <message>
        <source>Disconnect user</source>
        <translation>Disconnettere utente</translation>
    </message>
    <message>
        <source>Update is available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A new release of %1 is available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can download it here: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>configure</name>
    <message>
        <source>Configure</source>
        <translation>Configura</translation>
    </message>
    <message>
        <source>Autoconnect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Default host address:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Indirizzio dell&apos;host predefinito:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Default Username:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Nome utente predefinito:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Host Address</source>
        <translation>Indirizzo dell&apos;host</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Interval:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Intervallo:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancella</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Username (default :  username = root)</source>
        <translation>Nome utente (predefinito :  nome utente = root)</translation>
    </message>
    <message>
        <source>Log SMB/CIFS activities</source>
        <translation></translation>
    </message>
    <message>
        <source>Status notification messages</source>
        <translation>Stato messaggi di notifica</translation>
    </message>
    <message>
        <source>Notifications and log</source>
        <translation>Notifiche e log</translation>
    </message>
    <message>
        <source>Limit log:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation>giorni</translation>
    </message>
    <message>
        <source>Iconize QtSmbstatus in system tray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Smbstatus</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Interval between smbstatus requests in seconds, (interval &gt; 2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show hidden shares (share$)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show hidden shares</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Connessione</translation>
    </message>
    <message>
        <source>Autoconnect on qtsmbstatus startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show activities in &quot;balloon messages&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Misc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatically Check for updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A new release is available</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>form_smbstatus</name>
    <message>
        <source>qtsmbstatus</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aiuto</translation>
    </message>
    <message>
        <source>&amp;About QtSmbstatus</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Informazioni su &amp;Qt</translation>
    </message>
    <message>
        <source>Connect/Disconnect</source>
        <translation>Connetti/Disconnetti</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Configure client</source>
        <translation>&amp;Configura client</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation>&amp;Cerca</translation>
    </message>
    <message>
        <source>&amp;Machine</source>
        <translation>&amp;Macchina</translation>
    </message>
    <message>
        <source>&amp;User</source>
        <translation>&amp;Utente</translation>
    </message>
    <message>
        <source>Share &amp;open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Locked file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;Avanti</translation>
    </message>
    <message>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <source>&amp;Find text</source>
        <translation>&amp;Trova testo</translation>
    </message>
    <message>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;File</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>Informazioni su Qt</translation>
    </message>
    <message>
        <source>Configure QtSmbstatus client</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search machine</source>
        <translation>Cerca macchina</translation>
    </message>
    <message>
        <source>Search user</source>
        <translation>Cerca utente</translation>
    </message>
    <message>
        <source>Search share open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search file open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Avanti</translation>
    </message>
    <message>
        <source>Find text</source>
        <translation>Trova testo</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Esci</translation>
    </message>
    <message>
        <source>Quit QtSmbstatus</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Co&amp;nnect</source>
        <translation>Co&amp;nnetti</translation>
    </message>
    <message>
        <source>&amp;Show CIFS/SMB activities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About QtSmbstatus</source>
        <translation>Informazioni su QtSmbstatus</translation>
    </message>
</context>
<context>
    <name>logform</name>
    <message>
        <source>View Activities</source>
        <translation>Visualizza attività</translation>
    </message>
    <message>
        <source>View/hide shares</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View/hide files</source>
        <translation>Visualizza/nascondi i file</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filtro:</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <source>Save log</source>
        <translation>Salva log</translation>
    </message>
</context>
<context>
    <name>login_dialog</name>
    <message>
        <source>login</source>
        <translation>accedi</translation>
    </message>
    <message>
        <source>exit</source>
        <translation>esci</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome  utente</translation>
    </message>
    <message>
        <source>root</source>
        <translation>root</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>Connect to qtsmbstatus server</source>
        <translation>Connettiti al server qtsmbstatus</translation>
    </message>
</context>
<context>
    <name>main_windows</name>
    <message>
        <source>Connect</source>
        <translation>Connettiti</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Disconetti</translation>
    </message>
    <message>
        <source>Invalid login or password !</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connection in progress on %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connected to host</source>
        <translation>Connesso all&apos;host</translation>
    </message>
    <message>
        <source>Connection closed</source>
        <translation>Connessione terminata</translation>
    </message>
</context>
</TS>

==> qtsmbstatus_2.2.1.orig.tar.gz: qtsmbstatus-2.2.1/client/tr/qtsmbstatus_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name></name>
    <message>
        <source></source>
        <translatorcomment>Italian translation for qtsmbstatus
Copyright (c) 2007 Rosetta Contributors and Canonical Ltd 2007
This file is distributed under the same license as the qtsmbstatus package.
FIRST AUTHOR &lt;EMAIL@ADDRESS&gt;, 2007.

</translatorcomment>
        <translation>Project-Id-Version: qtsmbstatus
Report-Msgid-Bugs-To: FULL NAME &lt;EMAIL@ADDRESS&gt;
POT-Creation-Date: 2008-11-12 21:25+0200
PO-Revision-Date: 2011-05-13 19:15+0000
Last-Translator: simone.sandri &lt;lexluxsox@hotmail.it&gt;
Language-Team: Italian &lt;it@li.org&gt;
MIME-Version: 1.0
Content-Type: text/plain; charset=UTF-8
Content-Transfer-Encoding: 8bit
X-Launchpad-Export-Date: 2011-06-27 16:20+0000
X-Generator: Launchpad (build 13265)
</translation>
    </message>
</context>
<context>
    <name>LogForm</name>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Machine</source>
        <translation>Macchina</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Utente</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Servizio</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Apri il file</translation>
    </message>
</context>
<context>
    <name>MainWindows</name>
    <message>
        <source>Show CIFS/SMB activities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>Configura</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>Minimizza</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Ripristina</translation>
    </message>
    <message>
        <source>Thanks to:</source>
        <translation>Ringraziamenti a:</translation>
    </message>
    <message>
        <source>This program is licensed to you under the terms of the GNU General Public License version 2</source>
        <translation>Questo programma ti è concesso in licenza in base ai termini della GNU General Public License versione 2</translation>
    </message>
    <message>
        <source>Find text</source>
        <translation>Trova testo</translation>
    </message>
    <message>
        <source>Text not found.</source>
        <translation>Testo non trovato.</translation>
    </message>
    <message>
        <source>User %1 has opened share %2 (%3)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User %1 has opened file %2 (%3)</source>
        <translation>L&apos;utente %1 ha aperto il file %2 (%3)</translation>
    </message>
    <message>
        <source>CIFS/SMB activities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Message to send</source>
        <translation>Messaggio da inviare</translation>
    </message>
    <message>
        <source>Message to send to %1:</source>
        <translation>Messaggio da inviare a %1:</translation>
    </message>
    <message>
        <source>Do you really want to disconnect user %1 ?</source>
        <translation>Si vuole davvero disconnettere l&apos;utente %1 ?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Si</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;No</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Proprieta&apos;</translation>
    </message>
    <message>
        <source>Send out message to all users</source>
        <translation>Spedire il messaggio a tutti gli utenti</translation>
    </message>
    <message>
        <source>Send out message to</source>
        <translation>Spedire il messaggio a</translation>
    </message>
    <message>
        <source>Disconnect user</source>
        <translation>Disconnettere utente</translation>
    </message>
    <message>
        <source>Update is available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A new release of %1 is available</source>
        <translation>È disponibile un nuovo rilascio di %1</translation>
    </message>
    <message>
        <source>You can download it here: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>configure</name>
    <message>
        <source>Configure</source>
        <translation>Configura</translation>
    </message>
    <message>
        <source>Smbstatus</source>
        <translation>Smbstatus</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Interval:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Intervallo:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Interval between smbstatus requests in seconds, (interval &gt; 2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show hidden shares (share$)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show hidden shares</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notifications and log</source>
        <translation>Notifiche e log</translation>
    </message>
    <message>
        <source>Limit log:</source>
        <translation>Limite del registro:</translation>
    </message>
    <message>
        <source>days</source>
        <translation>giorni</translation>
    </message>
    <message>
        <source>Iconize QtSmbstatus in system tray</source>
        <translation>Riduci a icona QtSmbstatus nel pannello di sistema</translation>
    </message>
    <message>
        <source>Show activities in &quot;balloon messages&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Status notification messages</source>
        <translation>Notifiche sullo stato</translation>
    </message>
    <message>
        <source>Log SMB/CIFS activities</source>
        <translation>Tieni un registro delle attività SMB/CIFS</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancella</translation>
    </message>
    <message>
        <source>Misc</source>
        <translation>Varie</translation>
    </message>
    <message>
        <source>Automatically Check for updates</source>
        <translation>Verifica disponibilità di nuove versioni automaticamente</translation>
    </message>
    <message>
        <source>A new release is available</source>
        <translation>Nuova versione disponibile</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Connessione</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Default Username:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Nome utente predefinito:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Autoconnect on qtsmbstatus startup</source>
        <translation>Connetti automaticamente all&apos;avvio di qtsmbstatus</translation>
    </message>
    <message>
        <source>Autoconnect</source>
        <translation>Connessione automatica</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Default host address:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Indirizzio dell&apos;host predefinito:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Username (default :  username = root)</source>
        <translation>Nome utente (predefinito : nome utente = root)</translation>
    </message>
    <message>
        <source>Host Address</source>
        <translation>Indirizzo dell&apos;host</translation>
    </message>
</context>
<context>
    <name>form_smbstatus</name>
    <message>
        <source>qtsmbstatus</source>
        <translation>qtsmbstatus</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Host:</translation>
    </message>
    <message>
        <source>Connect/Disconnect</source>
        <translation>Connetti/Disconnetti</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;File</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation>&amp;Cerca</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aiuto</translation>
    </message>
    <message>
        <source>&amp;About QtSmbstatus</source>
        <translation>Inform&amp;azioni su QtSmbstatus</translation>
    </message>
    <message>
        <source>About QtSmbstatus</source>
        <translation>Informazioni su QtSmbstatus</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Informazioni su &amp;Qt</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>Informazioni su Qt</translation>
    </message>
    <message>
        <source>&amp;Configure client</source>
        <translation>&amp;Configura client</translation>
    </message>
    <message>
        <source>Configure QtSmbstatus client</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Machine</source>
        <translation>&amp;Macchina</translation>
    </message>
    <message>
        <source>Search machine</source>
        <translation>Cerca macchina</translation>
    </message>
    <message>
        <source>&amp;User</source>
        <translation>&amp;Utente</translation>
    </message>
    <message>
        <source>Search user</source>
        <translation>Cerca utente</translation>
    </message>
    <message>
        <source>Share &amp;open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search share open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Locked file</source>
        <translation>&amp;File bloccato</translation>
    </message>
    <message>
        <source>Search file open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;Avanti</translation>
    </message>
    <message>
        <source>Next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <source>&amp;Find text</source>
        <translation>&amp;Trova testo</translation>
    </message>
    <message>
        <source>Find text</source>
        <translation>Trova testo</translation>
    </message>
    <message>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Esci</translation>
    </message>
    <message>
        <source>Quit QtSmbstatus</source>
        <translation>Esci da QtSmbstatus</translation>
    </message>
    <message>
        <source>&amp;Show CIFS/SMB activities</source>
        <translation>Mo&amp;stra le attività CIFS/SMB</translation>
    </message>
    <message>
        <source>Co&amp;nnect</source>
        <translation>Co&amp;nnetti</translation>
    </message>
</context>
<context>
    <name>logform</name>
    <message>
        <source>View Activities</source>
        <translation>Visualizza attività</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save log</source>
        <translation>Salva log</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <source>View/hide shares</source>
        <translation>Mostra/nascondi le condivisioni</translation>
    </message>
    <message>
        <source>View/hide files</source>
        <translation>Visualizza/nascondi i file</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filtro:</translation>
    </message>
</context>
<context>
    <name>login_dialog</name>
    <message>
        <source>Connect to qtsmbstatus server</source>
        <translation>Connettiti al server qtsmbstatus</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome  utente</translation>
    </message>
    <message>
        <source>root</source>
        <translation>root</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>login</source>
        <translation>accedi</translation>
    </message>
    <message>
        <source>exit</source>
        <translation>esci</translation>
    </message>
</context>
<context>
    <name>main_windows</name>
    <message>
        <source>Connect</source>
        <translation>Connettiti</translation>
    </message>
    <message>
        <source>Connection in progress on %1</source>
        <translation>Connessione in corso su %1</translation>
    </message>
    <message>
        <source>The server certificate doesn&apos;t contain valid data or expired !</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The authenticity of host &apos;%1&apos; can&apos;t be established.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SHA1 Fingerprint: %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to continue connecting ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connected to host</source>
        <translation>Connesso all&apos;host</translation>
    </message>
    <message>
        <source>Connection closed</source>
        <translation>Connessione terminata</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Disconetti</translation>
    </message>
    <message>
        <source>Invalid login or password !</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
